@@ -15,20 +15,7 @@ param_list_xgboost <- expand.grid(
   max_depth = seq(1, 5, 4)
 )
 
-if (isTRUE(as.logical(Sys.getenv("_R_CHECK_LIMIT_CORES_")))) {
-  # on cran
-  ncores <- 2L
-} else {
-  ncores <- ifelse(
-    test = parallel::detectCores() > 4,
-    yes = 4L,
-    no = ifelse(
-      test = parallel::detectCores() < 2L,
-      yes = 1L,
-      no = parallel::detectCores()
-    )
-  )
-}
+ncores <- 2L
 
 train_x <- model.matrix(
   ~ -1 + .,
